dot-heat_kinship: Kinship heatmaps (adapted from superheat)

.heat_kinshipR Documentation

Kinship heatmaps (adapted from superheat)

Description

Implements a subset of superheat behavior used by kinship.heatmap().

Usage

.heat_kinship(
  K,
  dendrogram = TRUE,
  clustering.method = c("hierarchical", "kmeans"),
  dist.method = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
  row.label = TRUE,
  col.label = FALSE
)

Arguments

K

A numeric matrix.

dendrogram

Logical. Draw a column dendrogram.

clustering.method

Clustering method. Supports "hierarchical" and "kmeans".

dist.method

Distance method passed to dist().

row.label

Logical. Draw row labels.

col.label

Logical. Draw column labels.

Details

Credits to the superheat package by Barter and Yu (2020).

Value

Invisibly returns a list, with plot, membership.cols, membership.rows, order.rows, order.cols, and heat.pal.values.


ASRgenomics documentation built on May 13, 2026, 1:07 a.m.