| .heat_kinship | R Documentation |
Implements a subset of superheat behavior used by kinship.heatmap().
.heat_kinship(
K,
dendrogram = TRUE,
clustering.method = c("hierarchical", "kmeans"),
dist.method = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
row.label = TRUE,
col.label = FALSE
)
K |
A numeric matrix. |
dendrogram |
Logical. Draw a column dendrogram. |
clustering.method |
Clustering method. Supports "hierarchical" and "kmeans". |
dist.method |
Distance method passed to dist(). |
row.label |
Logical. Draw row labels. |
col.label |
Logical. Draw column labels. |
Credits to the superheat package by Barter and Yu (2020).
Invisibly returns a list, with plot, membership.cols, membership.rows, order.rows, order.cols, and heat.pal.values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.