Learn R Programming

ASRgenomics (version 1.1.4)

ped.salmon: Pedigree data for Atlantic salmon dataset

Description

Pedigree data of 1,481 Atlantic salmon samples. Missing parental information coded as 0. Dataset obtained from supplementary material in Robledo et al. (2018).

Usage

ped.salmon

Arguments

Format

data.frame

References

Robledo D., Matika O., Hamilton A., and Houston R.D. 2018. Genome-wide association and genomic selection for resistance to amoebic gill disease in Atlantic salmon. G3 Genes, Genomes, Genetics 8:1195-1203.

Examples

Run this code
ped.salmon |> head()

Run the code above in your browser using DataLab